# Python Package Exercise

An exercise to create a Python package, build it, test it, distribute it, and use it. See [instructions](./instructions.md) for details.

## Team Members
- Yuhao Sheng (ys4689)
- Ryoma Nagano 
- Qiyun Yin
- Andrea Tang

## Description

`Fortunes` is a delightful Python package that brings a touch of randomness and inspiration into your projects. Whether you're looking for a daily dose of wisdom, a lucky number, or the ability to send personalized fortunes via email, Fortunes has you covered.

### Features
- __Random Fortune Generation:__ Retrieve one or multiple unique fortunes along with lucky numbers.
- __Email Integration:__ Send personalized fortunes to any email address effortlessly.
- __Customizable Quotes:__ Get your own collection of fortunes and quotes.

## Installation